pub const fn is_terminal_order_state(state: OKXOrderStatus) -> boolExpand description
Returns whether the venue order state admits no further fills.
pub const fn is_terminal_order_state(state: OKXOrderStatus) -> boolReturns whether the venue order state admits no further fills.